/*
 *  Copyright (c) 2008 Boudewijn Rempt <boud@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_IMAGE_COMMANDS
#define KIS_IMAGE_COMMANDS

#include "kis_image_change_layers_command.h"
#include "kis_image_command.h"
#include "kis_image_set_projection_color_space_command.h"
#include "kis_image_layer_add_command.h"
#include "kis_image_layer_move_command.h"
#include "kis_image_layer_remove_command.h"
#include "kis_image_lock_command.h"
#include "kis_image_resize_command.h"

#endif
